@@ -264,9 +264,9 @@ int editBuddies(const QStringList &newList, bool currentDiveOnly)
 	return execute_edit(new EditBuddies(newList, currentDiveOnly));
 }
 
-int editDiveMaster(const QStringList &newList, bool currentDiveOnly)
+int editDiveGuide(const QStringList &newList, bool currentDiveOnly)
 {
-	return execute_edit(new EditDiveMaster(newList, currentDiveOnly));
+	return execute_edit(new EditDiveGuide(newList, currentDiveOnly));
 }
 
 void pasteDives(const dive *d, dive_components what)
@@ -276,12 +276,12 @@ void pasteDives(const dive *d, dive_components what)
 
 void replanDive(dive *d)
 {
-	execute(new ReplanDive(d, false));
+	execute(new ReplanDive(d));
 }
 
-void editProfile(dive *d)
+void editProfile(const dive *d, EditProfileType type, int count)
 {
-	execute(new ReplanDive(d, true));
+	execute(new EditProfile(d, type, count));
 }
 
 int addWeight(bool currentDiveOnly)
@@ -314,6 +314,11 @@ int editCylinder(int index, cylinder_t cyl, EditCylinderType type, bool currentD
 	return execute_edit(new EditCylinder(index, cyl, type, currentDiveOnly));
 }
 
+void editSensors(int toCylinder, const int fromCylinder)
+{
+	execute(new EditSensors(toCylinder, fromCylinder));
+}
+
 // Trip editing related commands
 void editTripLocation(dive_trip *trip, const QString &s)
 {
