@@ -636,7 +636,7 @@ static void wlog_compl_parser(struct memblock *wl_mem, struct dive *dt_dive, int
 	 */
 	tmp = (int) two_bytes_to_int(runner[pos_weight + 1], runner[pos_weight]);
 	if (tmp != 0x7fff) {
-		weightsystem_t ws = { {lrint(tmp * 10)}, QT_TRANSLATE_NOOP("gettextFromC", "unknown") };
+		weightsystem_t ws = { {lrint(tmp * 10)}, QT_TRANSLATE_NOOP("gettextFromC", "unknown"), false };
 		add_cloned_weightsystem(&dt_dive->weightsystems, ws);
 	}
 
