@@ -123,7 +123,7 @@ void add_gas_switch_event(struct dive *dive, struct divecomputer *dc, int second
  * have to actually remove the existing event and replace it with a new one.
  * WARNING, WARNING... this may end up freeing event in case that event is indeed
  * WARNING, WARNING... part of this divecomputer on this dive! */
-void update_event_name(struct dive *d, struct event *event, const char *name)
+void update_event_name(struct dive *d, int dc_number, struct event *event, const char *name)
 {
 	if (!d || !event)
 		return;
@@ -224,7 +224,7 @@ static void free_dive_structures(struct dive *d)
 	fulltext_unregister(d);
 	/* free the strings */
 	free(d->buddy);
-	free(d->divemaster);
+	free(d->diveguide);
 	free(d->notes);
 	free(d->suit);
 	/* free tags, additional dive computers, and pictures */
@@ -272,7 +272,7 @@ static void copy_dive_nodc(const struct dive *s, struct dive *d)
 	d->full_text = NULL;
 	invalidate_dive_cache(d);
 	d->buddy = copy_string(s->buddy);
-	d->divemaster = copy_string(s->divemaster);
+	d->diveguide = copy_string(s->diveguide);
 	d->notes = copy_string(s->notes);
 	d->suit = copy_string(s->suit);
 	copy_cylinders(&s->cylinders, &d->cylinders);
@@ -319,7 +319,7 @@ void selective_copy_dive(const struct dive *s, struct dive *d, struct dive_compo
 	if (clear)
 		clear_dive(d);
 	CONDITIONAL_COPY_STRING(notes);
-	CONDITIONAL_COPY_STRING(divemaster);
+	CONDITIONAL_COPY_STRING(diveguide);
 	CONDITIONAL_COPY_STRING(buddy);
 	CONDITIONAL_COPY_STRING(suit);
 	if (what.rating)
@@ -2616,7 +2616,7 @@ struct dive *merge_dives(const struct dive *a, const struct dive *b, int offset,
 		*trip = get_preferred_trip(a, b);
 	MERGE_TXT(res, a, b, notes, "\n--\n");
 	MERGE_TXT(res, a, b, buddy, ", ");
-	MERGE_TXT(res, a, b, divemaster, ", ");
+	MERGE_TXT(res, a, b, diveguide, ", ");
 	MERGE_MAX(res, a, b, rating);
 	MERGE_TXT(res, a, b, suit, ", ");
 	MERGE_MAX(res, a, b, number);
@@ -3124,7 +3124,7 @@ struct dive *clone_delete_divecomputer(const struct dive *d, int dc_number)
  */
 void split_divecomputer(const struct dive *src, int num, struct dive **out1, struct dive **out2)
 {
-	struct divecomputer *srcdc = get_dive_dc(current_dive, dc_number);
+	const struct divecomputer *srcdc = get_dive_dc_const(src, num);
 
 	if (src && srcdc) {
 		// Copy the dive, but only using the selected dive computer
