@@ -32,7 +32,7 @@ struct dive {
 	timestamp_t when;
 	struct dive_site *dive_site;
 	char *notes;
-	char *divemaster, *buddy;
+	char *diveguide, *buddy;
 	struct cylinder_table cylinders;
 	struct weightsystem_table weightsystems;
 	char *suit;
@@ -78,7 +78,7 @@ extern int same_gasmix_cylinder(const cylinder_t *cyl, int cylid, const struct d
 struct dive_components {
 	unsigned int divesite : 1;
 	unsigned int notes : 1;
-	unsigned int divemaster : 1;
+	unsigned int diveguide : 1;
 	unsigned int buddy : 1;
 	unsigned int suit : 1;
 	unsigned int rating : 1;
@@ -115,7 +115,6 @@ extern bool autogroup;
 extern struct dive displayed_dive;
 extern unsigned int dc_number;
 extern struct dive *current_dive;
-#define current_dc (get_dive_dc(current_dive, dc_number))
 
 extern struct dive *get_dive(int nr);
 extern struct dive *get_dive_from_table(int nr, const struct dive_table *dt);
@@ -193,7 +192,7 @@ extern bool is_cylinder_used(const struct dive *dive, int idx);
 extern bool is_cylinder_prot(const struct dive *dive, int idx);
 extern void add_gas_switch_event(struct dive *dive, struct divecomputer *dc, int time, int idx);
 extern struct event *create_gas_switch_event(struct dive *dive, struct divecomputer *dc, int seconds, int idx);
-extern void update_event_name(struct dive *d, struct event *event, const char *name);
+extern void update_event_name(struct dive *d, int dc_number, struct event *event, const char *name);
 extern void per_cylinder_mean_depth(const struct dive *dive, struct divecomputer *dc, int *mean, int *duration);
 extern int get_cylinder_index(const struct dive *dive, const struct event *ev);
 extern struct gasmix get_gasmix_from_event(const struct dive *, const struct event *ev);
