@@ -84,8 +84,6 @@ struct preferences default_prefs = {
 	},
 	.planner_deco_mode = BUEHLMANN,
 	.vpmb_conservatism = 3,
-	.distance_threshold = 100,
-	.time_threshold = 300,
 #if defined(SUBSURFACE_MOBILE)
 	.cloud_timeout = 10,
 #else
