@@ -60,16 +60,16 @@ private:
 	unsigned int desc_written = 0;
 	int timeout;
 
-	QList<QUuid> telit = {
-		"{00000001-0000-1000-8000-008025000000}", // TELIT_DATA_RX
-		"{00000002-0000-1000-8000-008025000000}", // TELIT_DATA_TX
-		"{00000003-0000-1000-8000-008025000000}", // TELIT_CREDITS_RX
-		"{00000004-0000-1000-8000-008025000000}"  // TELIT_CREDITS_TX
+	QList<QBluetoothUuid> telit = {
+		QBluetoothUuid(QUuid("{00000001-0000-1000-8000-008025000000}")), // TELIT_DATA_RX
+		QBluetoothUuid(QUuid("{00000002-0000-1000-8000-008025000000}")), // TELIT_DATA_TX
+		QBluetoothUuid(QUuid("{00000003-0000-1000-8000-008025000000}")), // TELIT_CREDITS_RX
+		QBluetoothUuid(QUuid("{00000004-0000-1000-8000-008025000000}"))  // TELIT_CREDITS_TX
 	};
 
-	QList<QUuid> ublox = {
-		"{2456e1b9-26e2-8f83-e744-f34f01e9d703}", // UBLOX_DATA_RX, UBLOX_DATA_TX
-		"{2456e1b9-26e2-8f83-e744-f34f01e9d704}"  // UBLOX_CREDITS_RX, UBLOX_CREDITS_TX
+	QList<QBluetoothUuid> ublox = {
+		QBluetoothUuid(QUuid("{2456e1b9-26e2-8f83-e744-f34f01e9d703}")), // UBLOX_DATA_RX, UBLOX_DATA_TX
+		QBluetoothUuid(QUuid("{2456e1b9-26e2-8f83-e744-f34f01e9d704}"))  // UBLOX_CREDITS_RX, UBLOX_CREDITS_TX
 	};
 };
 
