@@ -1,6 +1,7 @@
 // SPDX-License-Identifier: GPL-2.0
 #include "subsurface-time.h"
 #include "subsurface-string.h"
+#include "gettext.h"
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -98,7 +99,7 @@ void utc_mkdate(timestamp_t timestamp, struct tm *tm)
 	tm->tm_mon = m;
 }
 
-timestamp_t utc_mktime(struct tm *tm)
+timestamp_t utc_mktime(const struct tm *tm)
 {
 	static const int mdays[] = {
 		0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334
@@ -213,3 +214,13 @@ extern char *format_datetime(timestamp_t timestamp)
 
 	return strdup(buf);
 }
+
+/* Turn month (0-12) into three-character short name */
+const char *monthname(int mon)
+{
+	static const char month_array[12][4] = {
+		QT_TRANSLATE_NOOP("gettextFromC", "Jan"), QT_TRANSLATE_NOOP("gettextFromC", "Feb"), QT_TRANSLATE_NOOP("gettextFromC", "Mar"), QT_TRANSLATE_NOOP("gettextFromC", "Apr"), QT_TRANSLATE_NOOP("gettextFromC", "May"), QT_TRANSLATE_NOOP("gettextFromC", "Jun"),
+		QT_TRANSLATE_NOOP("gettextFromC", "Jul"), QT_TRANSLATE_NOOP("gettextFromC", "Aug"), QT_TRANSLATE_NOOP("gettextFromC", "Sep"), QT_TRANSLATE_NOOP("gettextFromC", "Oct"), QT_TRANSLATE_NOOP("gettextFromC", "Nov"), QT_TRANSLATE_NOOP("gettextFromC", "Dec"),
+	};
+	return translate("gettextFromC", month_array[mon]);
+}
