@@ -8,7 +8,9 @@
 
 #include <QFileDialog>
 #include <QMessageBox>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QDesktopWidget>
+#endif
 #include <QSettings>
 #include <QShortcut>
 #include <QStatusBar>
@@ -109,7 +111,7 @@ extern "C" void showErrorFromC(char *buf)
 	emit MainWindow::instance()->showError(error);
 }
 
-MainWindow::MainWindow() : QMainWindow(),
+MainWindow::MainWindow() :
 	appState((ApplicationState)-1), // Invalid state
 	actionNextDive(nullptr),
 	actionPreviousDive(nullptr),
@@ -132,7 +134,9 @@ MainWindow::MainWindow() : QMainWindow(),
 	// for the "default" mode
 	mainTab.reset(new MainTab);
 	diveList.reset(new DiveListView);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 	mapWidget.reset(MapWidget::instance()); // Yes, this is ominous see comment in mapwidget.cpp.
+#endif
 	plannerWidgets.reset(new PlannerWidgets);
 	statistics.reset(new StatsWidget);
 	profile.reset(new ProfileWidget);
@@ -141,8 +145,6 @@ MainWindow::MainWindow() : QMainWindow(),
 
 	registerApplicationState(ApplicationState::Default, { true, { mainTab.get(), FLAG_NONE },  { profile.get(), FLAG_NONE },
 								    { diveList.get(), FLAG_NONE }, { mapWidget.get(), FLAG_NONE } });
-	registerApplicationState(ApplicationState::EditDive, { false, { mainTab.get(), FLAG_NONE },  { profile.get(), FLAG_NONE },
-								      { diveList.get(), FLAG_NONE }, { mapWidget.get(), FLAG_NONE } });
 	registerApplicationState(ApplicationState::PlanDive, { false, { &plannerWidgets->plannerWidget, FLAG_NONE },         { profile.get(), FLAG_NONE },
 								      { &plannerWidgets->plannerSettingsWidget, FLAG_NONE }, { &plannerWidgets->plannerDetails, FLAG_NONE } });
 	registerApplicationState(ApplicationState::EditPlannedDive, { true, { &plannerWidgets->plannerWidget, FLAG_NONE }, { profile.get(), FLAG_NONE },
@@ -198,7 +200,9 @@ MainWindow::MainWindow() : QMainWindow(),
 	initialUiSetup();
 	readSettings();
 	diveList->setFocus();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 	MapWidget::instance()->reload();
+#endif
 	diveList->expand(diveList->model()->index(0, 0));
 	diveList->scrollTo(diveList->model()->index(0, 0), QAbstractItemView::PositionAtCenter);
 #ifdef NO_USERMANUAL
@@ -210,8 +214,8 @@ MainWindow::MainWindow() : QMainWindow(),
 	updateManager = new UpdateManager(this);
 	undoAction = Command::undoAction(this);
 	redoAction = Command::redoAction(this);
-	undoAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_Z));
-	redoAction->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_Z));
+	undoAction->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_Z));
+	redoAction->setShortcut(QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_Z));
 	ui.menu_Edit->addActions({ undoAction, redoAction });
 
 #ifndef NO_PRINTING
@@ -240,8 +244,6 @@ MainWindow::MainWindow() : QMainWindow(),
 	set_git_update_cb(&updateProgress);
 	set_error_cb(&showErrorFromC);
 
-	connect(profile->view.get(), &ProfileWidget2::editCurrentDive, this, &MainWindow::editCurrentDive);
-
 // full screen support is buggy on Windows and Ubuntu.
 // require the FULLSCREEN_SUPPORT macro to enable it!
 #ifndef FULLSCREEN_SUPPORT
@@ -327,7 +329,9 @@ void MainWindow::selectionChanged()
 	if (current_dive)
 		enableDisableOtherDCsActions();
 	profile->plotCurrentDive();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 	MapWidget::instance()->selectionChanged();
+#endif
 }
 
 void MainWindow::on_actionNew_triggered()
@@ -434,8 +438,6 @@ void MainWindow::on_actionCloudstoragesave_triggered()
 
 	if (verbose)
 		qDebug() << "Saving cloud storage to:" << filename;
-	if (mainTab->isEditing())
-		mainTab->acceptChanges();
 	mainTab->stealFocus(); // Make sure that any currently edited field is updated before saving.
 
 	showProgressBar();
@@ -455,9 +457,7 @@ void MainWindow::on_actionCloudOnline_triggered()
 		return;
 
 	// Refuse to go online if there is an edit in progress
-	if (!isOffline &&
-	    (DivePlannerPointsModel::instance()->currentMode() != DivePlannerPointsModel::NOTHING ||
-	    mainTab->isEditing())) {
+	if (!isOffline && inPlanner()) {
 		QMessageBox::warning(this, tr("Warning"), tr("Please save or cancel the current dive edit before going online"));
 		// We didn't switch to online, therefore uncheck the checkbox
 		ui.actionCloudOnline->setChecked(false);
@@ -490,8 +490,7 @@ void MainWindow::on_actionCloudOnline_triggered()
 
 bool MainWindow::okToClose(QString message)
 {
-	if (DivePlannerPointsModel::instance()->currentMode() != DivePlannerPointsModel::NOTHING ||
-		mainTab->isEditing() ) {
+	if (inPlanner()) {
 		QMessageBox::warning(this, tr("Warning"), message);
 		return false;
 	}
@@ -508,7 +507,9 @@ void MainWindow::closeCurrentFile()
 	clear_dive_file_data(); // this clears all the core data structures and resets the models
 	setCurrentFile(nullptr);
 	diveList->setSortOrder(DiveTripModelBase::NR, Qt::DescendingOrder);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 	MapWidget::instance()->reload();
+#endif
 	if (!existing_filename)
 		setTitle();
 	disableShortcuts();
@@ -570,8 +571,8 @@ void MainWindow::enableShortcuts()
 	redoAction->setEnabled(true);
 	ui.actionPreviousDC->setShortcut(Qt::Key_Left);
 	ui.actionNextDC->setShortcut(Qt::Key_Right);
-	ui.copy->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_C));
-	ui.paste->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_V));
+	ui.copy->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_C));
+	ui.paste->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_V));
 }
 
 void MainWindow::showProfile()
@@ -612,30 +613,29 @@ void MainWindow::on_actionDivelogs_de_triggered()
 	DivelogsDeWebServices::instance()->downloadDives();
 }
 
+bool MainWindow::inPlanner()
+{
+	return DivePlannerPointsModel::instance()->currentMode() == DivePlannerPointsModel::PLAN;
+}
+
 bool MainWindow::plannerStateClean()
 {
 	if (progressDialog)
 		// we are accessing the cloud, so let's not switch into Add or Plan mode
 		return false;
 
-	if (DivePlannerPointsModel::instance()->currentMode() != DivePlannerPointsModel::NOTHING ||
-		mainTab->isEditing()) {
+	if (inPlanner()) {
 		QMessageBox::warning(this, tr("Warning"), tr("Please save or cancel the current dive edit before trying to add a dive."));
 		return false;
 	}
 	return true;
 }
 
-void MainWindow::refreshProfile()
-{
-	showProfile();
-}
-
 void MainWindow::planCanceled()
 {
 	// while planning we might have modified the displayed_dive
 	// let's refresh what's shown on the profile
-	refreshProfile();
+	showProfile();
 	refreshDisplay();
 }
 
@@ -724,9 +724,9 @@ void MainWindow::on_actionYearlyStatistics_triggered()
 	l->addWidget(view);
 	d.resize(lrint(width() * .8), height() / 2);
 	d.move(lrint(width() * .1), height() / 4);
-	QShortcut *close = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_W), &d);
+	QShortcut *close = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_W), &d);
 	connect(close, SIGNAL(activated()), &d, SLOT(close()));
-	QShortcut *quit = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_Q), &d);
+	QShortcut *quit = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_Q), &d);
 	connect(quit, SIGNAL(activated()), this, SLOT(close()));
 	d.setWindowFlags(Qt::Window | Qt::CustomizeWindowHint
 		| Qt::WindowCloseButtonHint | Qt::WindowTitleHint | Qt::WindowMaximizeButtonHint);
@@ -799,9 +799,13 @@ void MainWindow::restoreSplitterSizes()
 		topSplitter->restoreState(settings.value("topSplitter").toByteArray());
 		bottomSplitter->restoreState(settings.value("bottomSplitter").toByteArray());
 	} else {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 		const int appH = qApp->desktop()->size().height();
 		const int appW = qApp->desktop()->size().width();
-
+#else
+		const int appH = screen()->size().height();
+		const int appW = screen()->size().width();
+#endif
 		ui.mainSplitter->setSizes({ appH * 3 / 5, appH * 2 / 5 });
 		topSplitter->setSizes({ appW / 2, appW / 2 });
 		bottomSplitter->setSizes({ appW * 3 / 5, appW * 2 / 5 });
@@ -1031,8 +1035,7 @@ void MainWindow::writeSettings()
 
 void MainWindow::closeEvent(QCloseEvent *event)
 {
-	if (DivePlannerPointsModel::instance()->currentMode() != DivePlannerPointsModel::NOTHING ||
-		mainTab->isEditing()) {
+	if (inPlanner()) {
 		on_actionQuit_triggered();
 		event->ignore();
 		return;
@@ -1179,9 +1182,6 @@ int MainWindow::file_save_as(void)
 	if (filename.isNull() || filename.isEmpty())
 		return report_error("No filename to save into");
 
-	if (mainTab->isEditing())
-		mainTab->acceptChanges();
-
 	if (save_dives(qPrintable(filename)))
 		return -1;
 
@@ -1203,9 +1203,6 @@ int MainWindow::file_save(void)
 	if (is_cloud && !saveToCloudOK())
 		return -1;
 
-	if (mainTab->isEditing())
-		mainTab->acceptChanges();
-
 	current_default = prefs.default_filename;
 	if (strcmp(existing_filename, current_default) == 0) {
 		/* if we are using the default filename the directory
@@ -1394,25 +1391,6 @@ void MainWindow::on_actionImportDiveSites_triggered()
 	divesiteImport.exec();
 }
 
-void MainWindow::editCurrentDive()
-{
-	// We only allow editing of the profile for manually added dives.
-	if (!current_dive || (!same_string(current_dive->dc.model, "manually added dive") && current_dive->dc.samples) || !userMayChangeAppState())
-		return;
-
-	// This shouldn't be possible, but let's make sure no weird "double editing" takes place.
-	if (mainTab->isEditing() || DivePlannerPointsModel::instance()->currentMode() != DivePlannerPointsModel::NOTHING)
-		return;
-
-	disableShortcuts(false);
-	copy_dive(current_dive, &displayed_dive); // Work on a copy of the dive
-	DivePlannerPointsModel::instance()->setPlanMode(DivePlannerPointsModel::ADD);
-	DivePlannerPointsModel::instance()->loadFromDive(&displayed_dive);
-	profile->setEditState(&displayed_dive, 0);
-	setApplicationState(ApplicationState::EditDive);
-	mainTab->enableEdition();
-}
-
 void MainWindow::on_actionExport_triggered()
 {
 	DiveLogExportDialog diveLogExport;
