@@ -54,7 +54,6 @@ public:
 
 	enum class ApplicationState {
 		Default,
-		EditDive,
 		PlanDive,
 		EditPlannedDive,
 		EditDiveSite,
@@ -71,7 +70,6 @@ public:
 	void importFiles(const QStringList importFiles);
 	void setToolButtonsEnabled(bool enabled);
 	void setApplicationState(ApplicationState state);
-	bool inPlanner();
 	NotificationWidget *getNotificationWidget();
 	void enableDisableCloudActions();
 	void enableDisableOtherDCsActions();
@@ -152,10 +150,6 @@ signals:
 public
 slots:
 	void readSettings();
-	void refreshDisplay();
-	void showProfile();
-	void refreshProfile();
-	void editCurrentDive();
 	void planCanceled();
 	void planCreated();
 	// Some shortcuts like "change DC" or "copy/paste dive components"
@@ -188,6 +182,8 @@ private:
 	void showProgressBar();
 	void hideProgressBar();
 	void writeSettings();
+	void refreshDisplay();
+	void showProfile();
 	int file_save();
 	int file_save_as();
 	void saveSplitterSizes();
@@ -197,6 +193,7 @@ private:
 	UpdateManager *updateManager;
 	std::unique_ptr<LocationInformationWidget> diveSiteEdit;
 
+	bool inPlanner();
 	bool plannerStateClean();
 	void setupSocialNetworkMenu();
 	QDialog *findMovedImagesDialog;
