@@ -45,9 +45,9 @@ RenumberDialog::RenumberDialog(bool selectedOnlyIn, QWidget *parent) : QDialog(p
 {
 	ui.setupUi(this);
 	connect(ui.buttonBox, SIGNAL(clicked(QAbstractButton *)), this, SLOT(buttonClicked(QAbstractButton *)));
-	QShortcut *close = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_W), this);
+	QShortcut *close = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_W), this);
 	connect(close, SIGNAL(activated()), this, SLOT(close()));
-	QShortcut *quit = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_Q), this);
+	QShortcut *quit = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_Q), this);
 	connect(quit, SIGNAL(activated()), parent, SLOT(close()));
 
 	if (selectedOnly && amount_selected == 1)
@@ -72,9 +72,9 @@ SetpointDialog::SetpointDialog(struct dive *dIn, int dcNrIn, int seconds) : QDia
 {
 	ui.setupUi(this);
 	connect(ui.buttonBox, &QDialogButtonBox::clicked, this, &SetpointDialog::buttonClicked);
-	QShortcut *close = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_W), this);
+	QShortcut *close = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_W), this);
 	connect(close, &QShortcut::activated, this, &QDialog::close);
-	QShortcut *quit = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_Q), this);
+	QShortcut *quit = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_Q), this);
 	connect(quit, &QShortcut::activated, MainWindow::instance(), &QWidget::close);
 }
 
@@ -116,9 +116,9 @@ ShiftTimesDialog::ShiftTimesDialog(QWidget *parent) : QDialog(parent),
 	connect(ui.buttonBox, SIGNAL(clicked(QAbstractButton *)), this, SLOT(buttonClicked(QAbstractButton *)));
 	connect(ui.timeEdit, SIGNAL(timeChanged(const QTime)), this, SLOT(changeTime()));
 	connect(ui.backwards, SIGNAL(toggled(bool)), this, SLOT(changeTime()));
-	QShortcut *close = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_W), this);
+	QShortcut *close = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_W), this);
 	connect(close, SIGNAL(activated()), this, SLOT(close()));
-	QShortcut *quit = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_Q), this);
+	QShortcut *quit = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_Q), this);
 	connect(quit, SIGNAL(activated()), parent, SLOT(close()));
 }
 
@@ -144,7 +144,7 @@ void ShiftImageTimesDialog::syncCameraClicked()
 	ui.DCImage->setScene(scene);
 
 	dcImageEpoch = picture_get_timestamp(qPrintable(fileNames.at(0)));
-	QDateTime dcDateTime = QDateTime::fromTime_t(dcImageEpoch, Qt::UTC);
+	QDateTime dcDateTime = QDateTime::fromSecsSinceEpoch(dcImageEpoch, Qt::UTC);
 	ui.dcTime->setDateTime(dcDateTime);
 	connect(ui.dcTime, SIGNAL(dateTimeChanged(const QDateTime &)), this, SLOT(dcDateTimeChanged(const QDateTime &)));
 }
@@ -213,8 +213,8 @@ void ShiftImageTimesDialog::updateInvalid()
 	bool allValid = true;
 	ui.warningLabel->hide();
 	ui.invalidFilesText->hide();
-	QDateTime time_first = QDateTime::fromTime_t(first_selected_dive()->when, Qt::UTC);
-	QDateTime time_last = QDateTime::fromTime_t(last_selected_dive()->when, Qt::UTC);
+	QDateTime time_first = QDateTime::fromSecsSinceEpoch(first_selected_dive()->when, Qt::UTC);
+	QDateTime time_last = QDateTime::fromSecsSinceEpoch(last_selected_dive()->when, Qt::UTC);
 	if (first_selected_dive() == last_selected_dive()) {
 		ui.invalidFilesText->setPlainText(tr("Selected dive date/time") + ": " + time_first.toString());
 	} else {
@@ -229,7 +229,7 @@ void ShiftImageTimesDialog::updateInvalid()
 			continue;
 
 		// We've found an invalid image
-		time_first.setTime_t(timestamps[i] + m_amount);
+		time_first.setSecsSinceEpoch(timestamps[i] + m_amount);
 		if (timestamps[i] == 0)
 			ui.invalidFilesText->append(fileNames[i] + " - " + tr("No Exif date/time found"));
 		else
@@ -271,9 +271,9 @@ void ShiftImageTimesDialog::backwardsChanged(bool)
 URLDialog::URLDialog(QWidget *parent) : QDialog(parent)
 {
 	ui.setupUi(this);
-	QShortcut *close = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_W), this);
+	QShortcut *close = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_W), this);
 	connect(close, SIGNAL(activated()), this, SLOT(close()));
-	QShortcut *quit = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_Q), this);
+	QShortcut *quit = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_Q), this);
 	connect(quit, SIGNAL(activated()), parent, SLOT(close()));
 }
 
@@ -305,7 +305,7 @@ DiveComponentSelection::DiveComponentSelection(QWidget *parent, struct dive *tar
 	ui.setupUi(this);
 	what = _what;
 	UI_FROM_COMPONENT(divesite);
-	UI_FROM_COMPONENT(divemaster);
+	UI_FROM_COMPONENT(diveguide);
 	UI_FROM_COMPONENT(buddy);
 	UI_FROM_COMPONENT(rating);
 	UI_FROM_COMPONENT(visibility);
@@ -317,9 +317,9 @@ DiveComponentSelection::DiveComponentSelection(QWidget *parent, struct dive *tar
 	UI_FROM_COMPONENT(number);
 	UI_FROM_COMPONENT(when);
 	connect(ui.buttonBox, SIGNAL(clicked(QAbstractButton *)), this, SLOT(buttonClicked(QAbstractButton *)));
-	QShortcut *close = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_W), this);
+	QShortcut *close = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_W), this);
 	connect(close, SIGNAL(activated()), this, SLOT(close()));
-	QShortcut *quit = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_Q), this);
+	QShortcut *quit = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_Q), this);
 	connect(quit, SIGNAL(activated()), parent, SLOT(close()));
 }
 
@@ -327,7 +327,7 @@ void DiveComponentSelection::buttonClicked(QAbstractButton *button)
 {
 	if (current_dive && ui.buttonBox->buttonRole(button) == QDialogButtonBox::AcceptRole) {
 		COMPONENT_FROM_UI(divesite);
-		COMPONENT_FROM_UI(divemaster);
+		COMPONENT_FROM_UI(diveguide);
 		COMPONENT_FROM_UI(buddy);
 		COMPONENT_FROM_UI(rating);
 		COMPONENT_FROM_UI(visibility);
@@ -345,8 +345,8 @@ void DiveComponentSelection::buttonClicked(QAbstractButton *button)
 		text.setString(&cliptext);
 		if (what->divesite && current_dive->dive_site)
 			text << tr("Dive site: ") << current_dive->dive_site->name << "\n";
-		if (what->divemaster)
-			text << tr("Dive master: ") << current_dive->divemaster << "\n";
+		if (what->diveguide)
+			text << tr("Dive guide: ") << current_dive->diveguide << "\n";
 		if (what->buddy)
 			text << tr("Buddy: ") << current_dive->buddy << "\n";
 		if (what->rating)
