@@ -75,11 +75,10 @@ public:
 	bool matchAll();
 private
 slots:
-	void buttonClicked(QAbstractButton *button);
 	void syncCameraClicked();
 	void dcDateTimeChanged(const QDateTime &);
-	void timeEditChanged(const QTime &time);
-	void timeEditChanged();
+	void timeEdited(const QString &timeText);
+	void backwardsChanged(bool);
 	void updateInvalid();
 	void matchAllImagesToggled(bool);
 
