@@ -55,6 +55,7 @@
 #include "commands/command.h"
 
 #if defined(Q_OS_ANDROID)
+#include <QtAndroid>
 #include "core/serial_usb_android.h"
 std::vector<android_usb_serial_device_descriptor> androidSerialDevices;
 
@@ -206,13 +207,11 @@ QMLManager::QMLManager() :
 	m_initialized(false),
 	m_pluggedInDeviceName(""),
 	m_showNonDiveComputers(false),
-	undoAction(Command::undoAction(this)),
 	m_oldStatus(qPrefCloudStorage::CS_UNKNOWN)
 {
 	m_instance = this;
 	m_lastDevicePixelRatio = qApp->devicePixelRatio();
 	timer.start();
-
 	// make upload signals available in QML
 	// Remark: signal - signal connect
 	connect(uploadDiveLogsDE::instance(), &uploadDiveLogsDE::uploadFinish,
@@ -230,9 +229,11 @@ QMLManager::QMLManager() :
 
 #if defined(Q_OS_ANDROID) || defined(Q_OS_IOS)
 #if defined(Q_OS_ANDROID)
-	// on Android we first try the GenericDataLocation (typically /storage/emulated/0) and if that fails
-	// (as happened e.g. on a Sony Xperia phone) we try several other default locations, with the TempLocation as last resort
+	// on Android we first try the AppDataLocation (which allows sharing of files), then the
+	// GenericDataLocation (typically /storage/emulated/0), and if that fails (as happened e.g. on a
+	// Sony Xperia phone) we try several other default locations, with the TempLocation as last resort
 	QStringList fileLocations =
+		QStandardPaths::standardLocations(QStandardPaths::AppDataLocation) +
 		QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation) +
 		QStandardPaths::standardLocations(QStandardPaths::DocumentsLocation) +
 		QStandardPaths::standardLocations(QStandardPaths::DownloadLocation) +
@@ -260,7 +261,8 @@ QMLManager::QMLManager() :
 		appendTextToLog("Successfully opened logfile " + appLogFileName
 				+ " at " + QDateTime::currentDateTime().toString());
 		// if we were able to write the overall logfile, also write the libdivecomputer logfile
-		QString libdcLogFileName = appLogFileName.replace("/subsurface.log", "/libdivecomputer.log");
+		QString libdcLogFileName = appLogFileName;
+		libdcLogFileName = libdcLogFileName.replace("/subsurface.log", "/libdivecomputer.log");
 		// remove the existing libdivecomputer logfile so we don't copy an old one by mistake
 		QFile libdcLog(libdcLogFileName);
 		libdcLog.remove();
@@ -306,7 +308,7 @@ QMLManager::QMLManager() :
 
 	// Let's set some defaults to be copied so users don't necessarily need
 	// to know how to configure this
-	what.divemaster = true;
+	what.diveguide = true;
 	what.buddy = true;
 	what.suit = true;
 	what.tags = true;
@@ -330,6 +332,7 @@ QMLManager::QMLManager() :
 
 	// setup Command infrastructure
 	Command::init();
+	undoAction = Command::undoAction(this);
 }
 
 void QMLManager::applicationStateChanged(Qt::ApplicationState state)
@@ -458,7 +461,7 @@ void QMLManager::updateAllGlobalLists()
 {
 	emit buddyListChanged();
 	emit suitListChanged();
-	emit divemasterListChanged();
+	emit diveguideListChanged();
 	// TODO: It would be nice if we could export the list of locations via model/view instead of a Q_PROPERTY
 	emit locationListChanged();
 }
@@ -488,8 +491,25 @@ void QMLManager::copyAppLogToClipboard()
 
 bool QMLManager::createSupportEmail()
 {
+	QString messageBody = "Please describe your issue here and keep the logs below:\n\n\n\n";
+#if defined(Q_OS_ANDROID)
+	// let's use our nifty Java shareFile function
+	QAndroidJniObject activity = QtAndroid::androidActivity();
+	if (activity.isValid()) {
+		QAndroidJniObject applogfilepath = QAndroidJniObject::fromString(appLogFileName);
+		QAndroidJniObject libdcfilepath = QAndroidJniObject::fromString(logfile_name);
+		bool success = activity.callMethod<jboolean>("shareFiles",
+					"(Ljava/lang/String;Ljava/lang/String;)Z", // two string arguments, return bool
+					applogfilepath.object<jstring>(), libdcfilepath.object<jstring>());
+		qDebug() << __FUNCTION__ << "shareFiles" << (success ? "succeeded" : "failed");
+		if (success)
+			return true;
+	}
+	qDebug() << __FUNCTION__ << "failed to share the logFiles via intent, use the fall-back mail body method";
+#endif
 	QString mailToLink = "mailto:in-app-support@subsurface-divelog.org?subject=Subsurface-mobile support request";
-	mailToLink += "&body=Please describe your issue here and keep the logs below:\n\n\n\n";
+	mailToLink += "&body=";
+	mailToLink += messageBody;
 	mailToLink += getCombinedLogs();
 	if (QDesktopServices::openUrl(QUrl(mailToLink))) {
 		appendTextToLog("OS accepted support email");
@@ -945,6 +965,35 @@ bool QMLManager::checkDate(struct dive *d, QString date)
 				if (newDate.isValid())
 					goto parsed;
 			}
+			// if everything else failed - maybe the user is entering dives where they
+			// don't recall the time? So let's try date only patterns...
+			QRegularExpression usDateOnly("\\d+/\\d+/\\d+");
+			if (date.contains(usDateOnly)) {
+				newDate = QDateTime::fromString(date, "M/d/yy");
+				if (newDate.isValid())
+					goto parsed;
+				newDate = QDateTime::fromString(date, "M/d/yyyy");
+				if (newDate.isValid())
+					goto parsed;
+			}
+			QRegularExpression leDateOnly("\\d+\\.\\d+\\.\\d+");
+			if (date.contains(usDateOnly)) {
+				newDate = QDateTime::fromString(date, "d.M.yy");
+				if (newDate.isValid())
+					goto parsed;
+				newDate = QDateTime::fromString(date, "d.M.yyyy");
+				if (newDate.isValid())
+					goto parsed;
+			}
+			QRegularExpression isoDateOnly("\\d+-\\d+-\\d+");
+			if (date.contains(usDateOnly)) {
+				newDate = QDateTime::fromString(date, "yy-M-d");
+				if (newDate.isValid())
+					goto parsed;
+				newDate = QDateTime::fromString(date, "yyyy-M-d");
+				if (newDate.isValid())
+					goto parsed;
+			}
 		}
 parsed:
 		if (newDate.isValid()) {
@@ -1062,7 +1111,7 @@ bool QMLManager::checkDepth(dive *d, QString depth)
 
 // update the dive and return the notes field, stripped of the HTML junk
 void QMLManager::commitChanges(QString diveId, QString number, QString date, QString location, QString gps, QString duration, QString depth,
-			       QString airtemp, QString watertemp, QString suit, QString buddy, QString diveMaster, QString tags, QString weight, QString notes,
+			       QString airtemp, QString watertemp, QString suit, QString buddy, QString diveGuide, QString tags, QString weight, QString notes,
 			       QStringList startpressure, QStringList endpressure, QStringList gasmix, QStringList usedCylinder, int rating, int visibility, QString state)
 {
 	struct dive *orig = get_dive_by_uniq_id(diveId.toInt());
@@ -1083,7 +1132,7 @@ void QMLManager::commitChanges(QString diveId, QString number, QString date, QSt
 				      QStringLiteral("watertmp:'%1'\n").arg(watertemp) <<
 				      QStringLiteral("suit    :'%1'\n").arg(suit) <<
 				      QStringLiteral("buddy   :'%1'\n").arg(buddy) <<
-				      QStringLiteral("diveMstr:'%1'\n").arg(diveMaster) <<
+				      QStringLiteral("diveGde :'%1'\n").arg(diveGuide) <<
 				      QStringLiteral("tags    :'%1'\n").arg(tags) <<
 				      QStringLiteral("weight  :'%1'\n").arg(weight) <<
 				      QStringLiteral("state   :'%1'\n").arg(state);
@@ -1212,13 +1261,13 @@ void QMLManager::commitChanges(QString diveId, QString number, QString date, QSt
 		free(d->buddy);
 		d->buddy = copy_qstring(buddy);
 	}
-	if (d->divemaster != diveMaster) {
-		if (diveMaster.contains(",")){
-			diveMaster = diveMaster.replace(QRegularExpression("\\s*,\\s*"), ", ");
+	if (d->diveguide != diveGuide) {
+		if (diveGuide.contains(",")){
+			diveGuide = diveGuide.replace(QRegularExpression("\\s*,\\s*"), ", ");
 		}
 		diveChanged = true;
-		free(d->divemaster);
-		d->divemaster = copy_qstring(diveMaster);
+		free(d->diveguide);
+		d->diveguide = copy_qstring(diveGuide);
 	}
 	// normalize the tag list we have and the one we get from the UI
 	// try hard to deal with accidental white space issues
@@ -1523,12 +1572,12 @@ bool QMLManager::toggleNotes(bool toggle)
 	return what.notes;
 }
 
-bool QMLManager::toggleDiveMaster(bool toggle)
+bool QMLManager::toggleDiveGuide(bool toggle)
 {
 	if (toggle)
-		what.divemaster = what.divemaster ? false : true;
+		what.diveguide = what.diveguide ? false : true;
 
-	return what.divemaster;
+	return what.diveguide;
 }
 
 bool QMLManager::toggleBuddy(bool toggle)
@@ -1764,9 +1813,9 @@ QStringList QMLManager::buddyList() const
 	return buddyModel.stringList();
 }
 
-QStringList QMLManager::divemasterList() const
+QStringList QMLManager::diveguideList() const
 {
-	return divemasterModel.stringList();
+	return diveguideModel.stringList();
 }
 
 QStringList QMLManager::locationList() const
@@ -1826,8 +1875,6 @@ void QMLManager::writeToAppLogFile(QString logText)
 //HACK to color the system bar on Android, use qtandroidextras and call the appropriate Java methods
 //this code is based on code in the Kirigami example app for Android (under LGPL-2) Copyright 2017 Marco Martin
 
-#include <QtAndroid>
-
 // there doesn't appear to be an include that defines these in an easily accessible way
 // WindowManager.LayoutParams
 #define FLAG_TRANSLUCENT_STATUS 0x04000000
