@@ -32,7 +32,7 @@ class QMLManager : public QObject {
 	Q_PROPERTY(QString notificationText MEMBER m_notificationText WRITE setNotificationText NOTIFY notificationTextChanged)
 	Q_PROPERTY(QStringList suitList READ suitList NOTIFY suitListChanged)
 	Q_PROPERTY(QStringList buddyList READ buddyList NOTIFY buddyListChanged)
-	Q_PROPERTY(QStringList divemasterList READ divemasterList NOTIFY divemasterListChanged)
+	Q_PROPERTY(QStringList diveguideList READ diveguideList NOTIFY diveguideListChanged)
 	Q_PROPERTY(QStringList locationList READ locationList NOTIFY locationListChanged)
 	Q_PROPERTY(QStringList cylinderListInit READ cylinderListInit CONSTANT)
 	Q_PROPERTY(QStringList defaultCylinderListInit READ defaultCylinderListInit CONSTANT)
@@ -144,7 +144,7 @@ public:
 
 	QStringList suitList() const;
 	QStringList buddyList() const;
-	QStringList divemasterList() const;
+	QStringList diveguideList() const;
 	QStringList locationList() const;
 	QStringList cylinderListInit() const;
 	QStringList defaultCylinderListInit() const;
@@ -169,7 +169,7 @@ public slots:
 	void commitChanges(QString diveId, QString number, QString date, QString location, QString gps,
 			   QString duration, QString depth, QString airtemp,
 			   QString watertemp, QString suit, QString buddy,
-			   QString diveMaster, QString tags, QString weight, QString notes, QStringList startpressure,
+			   QString diveGuide, QString tags, QString weight, QString notes, QStringList startpressure,
 			   QStringList endpressure, QStringList gasmix, QStringList usedCylinder, int rating, int visibility, QString state);
 	void updateTripDetails(QString tripIdString, QString tripLocation, QString tripNotes);
 	void removeDiveFromTrip(int id);
@@ -185,7 +185,7 @@ public slots:
 	void pasteDiveData(int id);
 	bool toggleDiveSite(bool toggle);
 	bool toggleNotes(bool toggle);
-	bool toggleDiveMaster(bool toggle);
+	bool toggleDiveGuide(bool toggle);
 	bool toggleBuddy(bool toggle);
 	bool toggleSuit(bool toggle);
 	bool toggleRating(bool toggle);
@@ -223,7 +223,7 @@ public slots:
 private:
 	BuddyCompletionModel buddyModel;
 	SuitCompletionModel suitModel;
-	DiveMasterCompletionModel divemasterModel;
+	DiveGuideCompletionModel diveguideModel;
 	DiveSiteSortedModel locationModel;
 	QString m_startPageText;
 	QString m_lastError;
@@ -280,7 +280,7 @@ signals:
 	void btEnabledChanged();
 	void suitListChanged();
 	void buddyListChanged();
-	void divemasterListChanged();
+	void diveguideListChanged();
 	void locationListChanged();
 	void cloudCacheListChanged();
 	void waitingForPositionChanged();
