@@ -13,13 +13,14 @@ class DiveCartesianAxis;
 class TankItem : public QGraphicsRectItem
 {
 public:
-	explicit TankItem(const DiveCartesianAxis &axis);
-	void setData(const struct plot_info *plotInfo, const struct dive *d);
+	explicit TankItem(const DiveCartesianAxis &axis, double dpr);
+	void setData(const struct dive *d, int plotStartTime, int plotEndTime);
+	double height() const;
 
 private:
 	void createBar(int startTime, int stopTime, struct gasmix gas);
 	const DiveCartesianAxis &hAxis;
-	int plotEndTime;
+	double dpr;
 	QBrush air, nitrox, oxygen, trimix;
 	QList<QGraphicsRectItem *> rects;
 };
