@@ -28,21 +28,21 @@ CylindersModel *DivePlannerPointsModel::cylindersModel()
 	return &cylinders;
 }
 
-void DivePlannerPointsModel::removePoints(const QVector<int> &rows)
+void DivePlannerPointsModel::removePoints(const std::vector<int> &rows)
 {
-	if (!rows.count())
+	if (rows.empty())
 		return;
-	QVector<int> v2 = rows;
+	std::vector<int> v2 = rows;
 	std::sort(v2.begin(), v2.end());
 
-	for (int i = v2.count() - 1; i >= 0; i--) {
+	for (int i = (int)v2.size() - 1; i >= 0; i--) {
 		beginRemoveRows(QModelIndex(), v2[i], v2[i]);
 		divepoints.erase(divepoints.begin() + v2[i]);
 		endRemoveRows();
 	}
 }
 
-void DivePlannerPointsModel::removeSelectedPoints(const QVector<int> &rows)
+void DivePlannerPointsModel::removeSelectedPoints(const std::vector<int> &rows)
 {
 	removePoints(rows);
 
@@ -230,7 +230,7 @@ bool DivePlannerPointsModel::updateMaxDepth()
 
 void DivePlannerPointsModel::removeDeco()
 {
-	QVector<int> computedPoints;
+	std::vector<int> computedPoints;
 	for (int i = 0; i < rowCount(); i++) {
 		if (!at(i).entered)
 			computedPoints.push_back(i);
@@ -824,6 +824,7 @@ int DivePlannerPointsModel::addStop(int milimeters, int seconds, int cylinderid_
 	point.time = seconds;
 	point.cylinderid = cylinderid;
 	point.setpoint = ccpoint;
+	point.minimum_gas.mbar = 0;
 	point.entered = entered;
 	point.divemode = divemode;
 	point.next = NULL;
@@ -1086,7 +1087,11 @@ void DivePlannerPointsModel::updateDiveProfile()
 		// Since we're calling computeVariations asynchronously and plan_deco_state is allocated
 		// on the stack, it must be copied and freed by the worker-thread.
 		struct deco_state *plan_deco_state_copy = new deco_state(plan_deco_state);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+		QtConcurrent::run(&DivePlannerPointsModel::computeVariationsFreeDeco, this, plan_copy, plan_deco_state_copy);
+#else
 		QtConcurrent::run(this, &DivePlannerPointsModel::computeVariationsFreeDeco, plan_copy, plan_deco_state_copy);
+#endif
 #else
 		computeVariations(plan_copy, &plan_deco_state);
 #endif
@@ -1333,8 +1338,6 @@ void DivePlannerPointsModel::createPlan(bool replanCopy)
 	}
 
 	setPlanMode(NOTHING);
-	planCreated(); // This signal will exit the profile from planner state. This must be *before* adding the dive,
-		       // so that the Undo-commands update the display accordingly (see condition in updateDiveInfo().
 
 	// Now, add or modify the dive.
 	if (!current_dive || d->id != current_dive->id) {
@@ -1362,4 +1365,6 @@ void DivePlannerPointsModel::createPlan(bool replanCopy)
 	// Remove and clean the diveplan, so we don't delete
 	// the dive by mistake.
 	free_dps(&diveplan);
+
+	planCreated(); // This signal will exit the UI from planner state.
 }
