@@ -54,6 +54,7 @@ static QVariant dive_table_alignment(int column)
 	case DiveTripModelBase::PHOTOS:
 	case DiveTripModelBase::COUNTRY:
 	case DiveTripModelBase::BUDDIES:
+	case DiveTripModelBase::DIVEGUIDE:
 	case DiveTripModelBase::LOCATION:
 		return int(Qt::AlignLeft | Qt::AlignVCenter);
 	}
@@ -210,6 +211,55 @@ static QPixmap &getPhotoIcon(int idx)
 	return icons[idx];
 }
 
+// textual description of the meaning of a column for use in tooltips
+QString DiveTripModelBase::getDescription(int column)
+{
+	switch (column) {
+	case NR:
+		return tr("#");
+	case DATE:
+		return tr("Date");
+	case RATING:
+		return tr("Rating");
+	case DEPTH:
+		return tr("Depth(%1)").arg((get_units()->length == units::METERS) ? tr("m") : tr("ft"));
+	case DURATION:
+		return tr("Duration");
+	case TEMPERATURE:
+		return tr("Temp.(°%1)").arg((get_units()->temperature == units::CELSIUS) ? "C" : "F");
+	case TOTALWEIGHT:
+		return tr("Weight(%1)").arg((get_units()->weight == units::KG) ? tr("kg") : tr("lbs"));
+	case SUIT:
+		return tr("Suit");
+	case CYLINDER:
+		return tr("Cylinder");
+	case GAS:
+		return tr("Gas");
+	case SAC:
+		const char *unit;
+		get_volume_units(0, NULL, &unit);
+		return tr("SAC(%1)").arg(QString(unit).append(tr("/min")));
+	case OTU:
+		return tr("OTU");
+	case MAXCNS:
+		return tr("Max. CNS");
+	case TAGS:
+		return tr("Tags");
+	case PHOTOS:
+		return tr("Media before/during/after dive");
+	case COUNTRY:
+		return tr("Country");
+	case BUDDIES:
+		return tr("Buddy");
+	case DIVEGUIDE:
+		return tr("Dive guide");
+	case LOCATION:
+		return tr("Location");
+	default:
+		return QString();
+	}
+}
+
 QVariant DiveTripModelBase::diveData(const struct dive *d, int column, int role) const
 {
 #ifdef SUBSURFACE_MOBILE
@@ -234,7 +284,7 @@ QVariant DiveTripModelBase::diveData(const struct dive *d, int column, int role)
 	case MobileListModel::WaterTempRole: return get_temperature_string(d->watertemp, true);
 	case MobileListModel::SacRole: return formatSac(d);
 	case MobileListModel::SumWeightRole: return formatSumWeight(d);
-	case MobileListModel::DiveMasterRole: return d->divemaster;
+	case MobileListModel::DiveGuideRole: return d->diveguide;
 	case MobileListModel::BuddyRole: return d->buddy;
 	case MobileListModel::TagsRole: return get_taglist_string(d->tag_list);
 	case MobileListModel::NotesRole: return formatNotes(d);
@@ -296,6 +346,8 @@ QVariant DiveTripModelBase::diveData(const struct dive *d, int column, int role)
 			return QString(get_dive_country(d));
 		case BUDDIES:
 			return QString(d->buddy);
+		case DIVEGUIDE:
+			return QString(d->diveguide);
 		case LOCATION:
 			return QString(get_dive_location(d));
 		case GAS:
@@ -323,47 +375,7 @@ QVariant DiveTripModelBase::diveData(const struct dive *d, int column, int role)
 		}
 		break;
 	case Qt::ToolTipRole:
-		switch (column) {
-		case NR:
-			return tr("#");
-		case DATE:
-			return tr("Date");
-		case RATING:
-			return tr("Rating");
-		case DEPTH:
-			return tr("Depth(%1)").arg((get_units()->length == units::METERS) ? tr("m") : tr("ft"));
-		case DURATION:
-			return tr("Duration");
-		case TEMPERATURE:
-			return tr("Temp.(°%1)").arg((get_units()->temperature == units::CELSIUS) ? "C" : "F");
-		case TOTALWEIGHT:
-			return tr("Weight(%1)").arg((get_units()->weight == units::KG) ? tr("kg") : tr("lbs"));
-		case SUIT:
-			return tr("Suit");
-		case CYLINDER:
-			return tr("Cylinder");
-		case GAS:
-			return tr("Gas");
-		case SAC:
-			const char *unit;
-			get_volume_units(0, NULL, &unit);
-			return tr("SAC(%1)").arg(QString(unit).append(tr("/min")));
-		case OTU:
-			return tr("OTU");
-		case MAXCNS:
-			return tr("Max. CNS");
-		case TAGS:
-			return tr("Tags");
-		case PHOTOS:
-			return tr("Media before/during/after dive");
-		case COUNTRY:
-			return tr("Country");
-		case BUDDIES:
-			return tr("Buddy");
-		case LOCATION:
-			return tr("Location");
-		}
-		break;
+		return getDescription(column);
 	case STAR_ROLE:
 		return d->rating;
 	case DIVE_ROLE:
@@ -427,50 +439,14 @@ QVariant DiveTripModelBase::headerData(int section, Qt::Orientation orientation,
 			return tr("Country");
 		case BUDDIES:
 			return tr("Buddy");
+		case DIVEGUIDE:
+			return tr("Dive guide");
 		case LOCATION:
 			return tr("Location");
 		}
 		break;
 	case Qt::ToolTipRole:
-		switch (section) {
-		case NR:
-			return tr("#");
-		case DATE:
-			return tr("Date");
-		case RATING:
-			return tr("Rating");
-		case DEPTH:
-			return tr("Depth(%1)").arg((get_units()->length == units::METERS) ? tr("m") : tr("ft"));
-		case DURATION:
-			return tr("Duration");
-		case TEMPERATURE:
-			return tr("Temp.(°%1)").arg((get_units()->temperature == units::CELSIUS) ? "C" : "F");
-		case TOTALWEIGHT:
-			return tr("Weight(%1)").arg((get_units()->weight == units::KG) ? tr("kg") : tr("lbs"));
-		case SUIT:
-			return tr("Suit");
-		case CYLINDER:
-			return tr("Cylinder");
-		case GAS:
-			return tr("Gas");
-		case SAC:
-			const char *unit;
-			get_volume_units(0, NULL, &unit);
-			return tr("SAC(%1)").arg(QString(unit).append(tr("/min")));
-		case OTU:
-			return tr("OTU");
-		case MAXCNS:
-			return tr("Max CNS");
-		case TAGS:
-			return tr("Tags");
-		case PHOTOS:
-			return tr("Media before/during/after dive");
-		case BUDDIES:
-			return tr("Buddy");
-		case LOCATION:
-			return tr("Location");
-		}
-		break;
+		return getDescription(section);
 	}
 
 	return QVariant();
@@ -1772,6 +1748,8 @@ bool DiveTripModelList::lessThan(const QModelIndex &i1, const QModelIndex &i2) c
 		return lessThanHelper(strCmp(get_dive_country(d1), get_dive_country(d2)), row_diff);
 	case BUDDIES:
 		return lessThanHelper(strCmp(d1->buddy, d2->buddy), row_diff);
+	case DIVEGUIDE:
+		return lessThanHelper(strCmp(d1->diveguide, d2->diveguide), row_diff);
 	case LOCATION:
 		return lessThanHelper(strCmp(get_dive_location(d1), get_dive_location(d2)), row_diff);
 	}
