@@ -221,12 +221,17 @@ echo Building from "$SRC", installing in "$INSTALL_ROOT"
 # find qmake
 if [ -n "$CMAKE_PREFIX_PATH" ] ; then
 	QMAKE=$CMAKE_PREFIX_PATH/../../bin/qmake
-else
+fi
+if [[ -z $QMAKE  ||  ! -x $QMAKE ]] ; then
 	hash qmake > /dev/null 2> /dev/null && QMAKE=qmake
 	[ -z $QMAKE ] && hash qmake-qt5 > /dev/null 2> /dev/null && QMAKE=qmake-qt5
-	[ -z $QMAKE ] && echo "cannot find qmake or qmake-qt5" && exit 1
+	[ -z $QMAKE ] && hash qmake-qt6 > /dev/null 2> /dev/null && QMAKE=qmake-qt6
+	[ -z $QMAKE ] && echo "cannot find qmake, qmake-qt5, or qmake-qt6" && exit 1
 fi
 
+# grab the Qt version
+QT_VERSION=$($QMAKE -query QT_VERSION)
+
 # it's not entirely clear why we only set this on macOS, but this appears to be what works
 if [ "$PLATFORM" = Darwin ] ; then
 	if [ -z "$CMAKE_PREFIX_PATH" ] ; then
@@ -244,9 +249,8 @@ fi
 
 # on Debian and Ubuntu based systems, the private QtLocation and
 # QtPositioning headers aren't bundled. Download them if necessary.
-if [ "$PLATFORM" = Linux ] ; then
+if [ "$PLATFORM" = Linux ] && [[ $QT_VERSION == 5* ]] ; then
 	QT_HEADERS_PATH=$($QMAKE -query QT_INSTALL_HEADERS)
-	QT_VERSION=$($QMAKE -query QT_VERSION)
 
 	if [ ! -d "$QT_HEADERS_PATH/QtLocation/$QT_VERSION/QtLocation/private" ] &&
            [ ! -d "$INSTALL_ROOT"/include/QtLocation/private ] ; then
@@ -260,7 +264,7 @@ if [ "$PLATFORM" = Linux ] ; then
 		rm -rf "$INSTALL_ROOT"/include/QtLocation > /dev/null 2>&1
 		rm -rf "$INSTALL_ROOT"/include/QtPositioning > /dev/null 2>&1
 
-		git clone --branch "v$QT_VERSION" git://code.qt.io/qt/qtlocation.git --depth=1 $QTLOC_GIT
+		git clone --branch "v$QT_VERSION" https://code.qt.io/qt/qtlocation.git --depth=1 $QTLOC_GIT
 
 		mkdir -p "$QTLOC_PRIVATE"
 		cd $QTLOC_GIT/src/location
@@ -348,7 +352,8 @@ if [[ $PLATFORM = Darwin && "$BUILD_DEPS" == "1" ]] ; then
 	pushd openssl
 	mkdir -p build
 	cd build
-	../Configure --prefix="$INSTALL_ROOT" --openssldir="$INSTALL_ROOT" "$OLDER_MAC" darwin64-x86_64-cc
+	if [ $(arch) == "arm64" ] ; then OS_ARCH=darwin64-arm64-cc ; else OS_ARCH=darwin64-x86_64-cc; fi
+	../Configure --prefix="$INSTALL_ROOT" --openssldir="$INSTALL_ROOT" "$OLDER_MAC" $OS_ARCH
 	make depend
 	# all the tests fail because the assume that openssl is already installed. Odd? Still thinks work
 	make -j4 -k
@@ -436,6 +441,7 @@ if [[ $PLATFORM = Darwin && "$BUILD_DEPS" == "1" ]] ; then
 
 	./${SRC_DIR}/scripts/get-dep-lib.sh single . libmtp
 	pushd libmtp
+	patch -p1 < ../${SRC_DIR}/scripts/libmtp.patch
 	echo 'N' | NOCONFIGURE="1" bash ./autogen.sh
 	mkdir -p build
 	cd build
@@ -504,7 +510,7 @@ STATIC_LIBDC="$INSTALL_ROOT/$(grep ^libdir Makefile | cut -d/ -f2)/libdivecomput
 
 cd "$SRC"
 
-if [ "$QUICK" != "1" ] && [ "$BUILD_DESKTOP$BUILD_MOBILE" != "" ] ; then
+if [ "$QUICK" != "1" ] && [ "$BUILD_DESKTOP$BUILD_MOBILE" != "" ] && [[ $QT_VERSION == 5* ]] ; then
 	# build the googlemaps map plugin
 
 	cd "$SRC"
