@@ -2,9 +2,13 @@
 #include <QQmlEngine>
 #include <QQuickItem>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include "map-widget/qmlmapwidgethelper.h"
 #include "qt-models/maplocationmodel.h"
+#endif
+
 #include "stats/statsview.h"
+#include "core/globals.h"
 #include "core/qt-gui.h"
 #include "core/settings/qPref.h"
 #include "core/ssrf.h"
@@ -54,16 +58,14 @@ void init_ui()
 #ifndef SUBSURFACE_MOBILE
 	register_qml_types(NULL);
 
-	MainWindow *window = new MainWindow();
+	MainWindow *window = make_global<MainWindow>();
 	window->setTitle();
 #endif // SUBSURFACE_MOBILE
 }
 
 void exit_ui()
 {
-#ifndef SUBSURFACE_MOBILE
-	delete MainWindow::instance();
-#endif // SUBSURFACE_MOBILE
+	free_globals();
 	free((void *)existing_filename);
 }
 
@@ -222,7 +224,9 @@ static void register_qml_types(QQmlEngine *engine)
 	register_qml_type<ChartListModel>("ChartListModel");
 #endif // not SUBSURFACE_MOBILE
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 	register_qml_type<MapWidgetHelper>("MapWidgetHelper");
 	register_qml_type<MapLocationModel>("MapLocationModel");
+#endif
 	register_qml_type<StatsView>("StatsView");
 }
