@@ -1,9 +1,9 @@
-var itemsToShow = new Array();	//list of indexes to all dives to view
+var itemsToShow = new Array();	//list of indices to all dives to view
 var items = new Array();
 var start;			//index of first element viewed in itemsToShow
 var sizeofpage;			//size of viewed page
 var numberofwords = 0;		//just for stats
-var olditemstoshow;		//to reference the indexes to all dives if changed
+var olditemstoshow;		//to reference the indices to all dives if changed
 //////////////////////////////////
 //				//
 //		View Model	//
@@ -20,6 +20,7 @@ function showAllDives()
 	for (var i = 0; i < items.length; i++) {
 		itemsToShow.push(i);
 	}
+	change_sort_col('1');
 	olditemstoshow = itemsToShow;
 	start = 0;
 	viewInPage();
@@ -39,15 +40,15 @@ function viewInPage()
 }
 
 /**
-*addHTML this Method puts the HTML of items of given indexes
-*@param {array} indexes array of indexes to put in HTML
+*addHTML this Method puts the HTML of items of given indices
+*@param {array} indices array of indices to put in HTML
 */
 function updateView(start, end)
 {
 	var divelist = document.getElementById('diveslist');
 	divelist.innerHTML = "";
 	for (var i = start; i <= end; i++) {
-		divelist.innerHTML += '<ul id="' + itemsToShow[i] + '" onclick="toggleExpantion(this)"</ul>';
+		divelist.innerHTML += '<ul id="' + itemsToShow[i] + '" onclick="toggleExpansion(event, this)"></ul>';
 		expand(document.getElementById(itemsToShow[i]));
 		items[itemsToShow[i]].expanded = true;
 	};
@@ -55,17 +56,17 @@ function updateView(start, end)
 }
 
 /**
-*addHTML this Method puts the HTML of items of given indexes
-*@param {array} indexes array of indexes to put in HTML
+*addHTML this Method puts the HTML of items of given indices
+*@param {array} indices array of indices to put in HTML
 */
-function addHTML(indexes)
+function addHTML(indices)
 {
 	var divelist = document.getElementById('diveslist');
 	divelist.innerHTML = "";
-	for (var i = 0; i < indexes.length; i++) {
-		divelist.innerHTML += '<ul id="' + indexes[i] + '" onclick="toggleExpantion(this)"</ul>';
-		expand(document.getElementById(indexes[i]));
-		itemsToShow[indexes[i]].expanded = true;
+	for (var i = 0; i < indices.length; i++) {
+		divelist.innerHTML += '<ul id="' + indices[i] + '" onclick="toggleExpansion(event, this)"></ul>';
+		expand(document.getElementById(indices[i]));
+		itemsToShow[indices[i]].expanded = true;
 	};
 }
 
@@ -134,14 +135,19 @@ function view_pagging(start, end)
 */
 function expandAll()
 {
-	console.time('expnadAll');
-	for (var i = start; i < start + sizeofpage; i++) {
-		if (i >= itemsToShow.length)
-			break;
-		unexpand(document.getElementById(itemsToShow[i]));
-		items[itemsToShow[i]].expanded = false;
+	if (tripsShown) {
+		for (var i = 0 ; i < trips.length ; i++) {
+			if (trips[i].expanded === false)
+				expand_trip(i);
+		}
+	} else {
+		for (var i = start; i < start + sizeofpage; i++) {
+			if (i >= itemsToShow.length)
+				break;
+			unexpand(document.getElementById(itemsToShow[i]));
+			items[itemsToShow[i]].expanded = false;
+		}
 	}
-	console.timeEnd('expnadAll');
 }
 
 /**
@@ -149,11 +155,18 @@ function expandAll()
 */
 function collapseAll()
 {
-	for (var i = start; i < start + sizeofpage; i++) {
-		if (i >= itemsToShow.length)
-			break;
-		expand(document.getElementById(itemsToShow[i]));
-		items[itemsToShow[i]].expanded = true;
+	if (tripsShown) {
+		for (var i = 0 ; i < trips.length ; i++) {
+			if (trips[i].expanded === true)
+				unexpand_trip(i);
+		}
+	} else {
+		for (var i = start; i < start + sizeofpage; i++) {
+			if (i >= itemsToShow.length)
+				break;
+			expand(document.getElementById(itemsToShow[i]));
+			items[itemsToShow[i]].expanded = true;
+		}
 	}
 }
 
@@ -161,12 +174,14 @@ function setNumberOfDives(e)
 {
 	var value = e.options[e.selectedIndex].value;
 	sizeofpage = parseInt(value, 10);
-	var end = start + sizeofpage - 1;
 	viewInPage();
 }
 
-function toggleExpantion(ul)
+function toggleExpansion(e, ul)
 {
+	if (e.target.localName === "a" ) {
+		return;
+	}
 	if (!items[ul.id].expanded) {
 		expand(ul);
 		items[ul.id].expanded = true;
@@ -200,22 +215,21 @@ function getlimited(dive)
 	       '<div class="item">' + dive.date + '</div>' +
 	       '<div class="item">' + dive.time + '</div>' +
 	       '<div class="item_large">' + dive.location + '</div>' +
-	       '<div class="item">' + dive.temperature.air + '</div>' +
-	       '<div class="item">' + dive.temperature.water + '</div></div>';
+	       '<div class="item">' + dive.dive_duration + '</div>' +
+	       '<div class="item">' + put_depth_unit(dive.maxdepth) + " " + depth_unit + '</div></div>';
 };
 
 function getExpanded(dive)
 {
 	var res = '<table><tr><td class="words">' + translate.Date + ': </td><td>' + dive.date +
 		  '</td><td class="words">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' + translate.Time + ': </td><td>' + dive.time +
-		  '</td><td class="words">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' + translate.Location + ': </td><td>' + '<a onclick=\"Search_list_Modules(\'' + dive.location + '\', {location:true, divemaster:false, buddy:false, notes:false, tags:false,})\">' + dive.location + '</a>' + getDiveCoor(dive) +
-		  '</td></tr></table><table><tr><td class="words">' + translate.Rating + ':</td><td>' + putRating(dive.rating) +
-		  '</td><td class="words">&nbsp;&nbsp;&nbsp;' + translate.Visibility + ':</td><td>' + putRating(dive.visibility) +
+		  '</td><td class="words">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' + translate.Location + ': </td><td>' + '<a onclick=\"Search_list_Modules(\'' + dive.location + '\', {location:true, diveguide:false, buddy:false, notes:false, tags:false,})\">' + dive.location + '</a>' + getDiveCoor(dive) +
 		  '</td></tr></table>' +
 		  '<table><tr><td class="words">' + translate.Air_Temp + ': </td><td>' + dive.temperature.air +
 		  '</td><td class="words">&nbsp;&nbsp;&nbsp;&nbsp;' + translate.Water_Temp + ': </td><td>' + dive.temperature.water +
-		  '</td></tr></table><table><tr><td class="words">' + translate.Duration + ': </td><td>' + dive.dive_duration +
-		  '</td></tr><tr><td class="words">' + translate.DiveMaster + ': </td><td>' + dive.divemaster +
+		  '</td><td class="words">&nbsp;&nbsp;&nbsp;&nbsp;' + translate.Rating + ':</td><td>' + putRating(dive.rating) +
+		  '</td></tr></table><table><tr><td class="words">' + translate.Max_Depth + ': </td><td>' + put_depth_unit(dive.maxdepth) + " " + depth_unit + '</td></tr><tr><td class="words">' + translate.Duration + ': </td><td>' + dive.dive_duration +
+		  '</td></tr><tr><td class="words">' + translate.DiveGuide + ': </td><td>' + dive.diveguide +
 		  '</td></tr><tr><td class="words"><p>' + translate.Buddy + ': </p></td><td>' + dive.buddy +
 		  '</td></tr><tr><td class="words">' + translate.Suit + ': </td><td>' + dive.suit +
 		  '</td></tr><tr><td class="words">' + translate.Tags + ': </td><td>' + putTags(dive.tags) +
@@ -230,7 +244,7 @@ function putTags(tags)
 {
 	var result = "";
 	for (var i in tags) {
-		result += '<a onclick=\"Search_list_Modules(\'' + tags[i] + '\', {location:false, divemaster:false, buddy:false, notes:false, tags:true,})\">' + tags[i] + '</a>';
+		result += '<a onclick=\"Search_list_Modules(\'' + tags[i] + '\', {location:false, diveguide:false, buddy:false, notes:false, tags:true,})\">' + tags[i] + '</a>';
 		if (i < tags.length - 1)
 			result += ', ';
 	}
@@ -243,8 +257,7 @@ function putTags(tags)
 */
 function putRating(rating)
 {
-	var result;
-	result = '<div>';
+	var result = '<div>';
 	for (var i = 0; i < rating; i++)
 		result += ' &#9733; ';
 	for (var i = rating; i < 5; i++)
@@ -266,8 +279,8 @@ each col. sorted asc or des
 var number = true;
 var time = true;
 var date = true;
-var air = true;
-var water = true;
+var duration = true;
+var depth = true;
 var locat = true;
 
 /*
@@ -307,18 +320,18 @@ function list_sort(sortOn)
 			sort_it(sortOn, cmpTimeAsc);
 		}
 		break;
-	case '4': //Air temp
-		if (air) {
-			sort_it(sortOn, cmpAtempDes);
+	case '4': //Duration
+		if (duration) {
+			sort_it(sortOn, cmpDurDes);
 		} else {
-			sort_it(sortOn, cmpAtempAsc);
+			sort_it(sortOn, cmpDurAsc);
 		}
 		break;
-	case '5': //Water temp
-		if (water) {
-			sort_it(sortOn, cmpWtempDes);
+	case '5': //Max Depth
+		if (depth) {
+			sort_it(sortOn, cmpDepthDes);
 		} else {
-			sort_it(sortOn, cmpWtempAsc);
+			sort_it(sortOn, cmpDepthAsc);
 		}
 		break;
 	case '6': //Location
@@ -343,11 +356,11 @@ function toggle_sort_state(sortOn)
 	case '3': //time
 		time = 1 - time;
 		break;
-	case '4': //Air temp
-		air = 1 - air;
+	case '4': //Duration
+		duration = 1 - duration;
 		break;
-	case '5': //Water temp
-		water = 1 - water;
+	case '5': //depth
+		depth = 1 - depth;
 		break;
 	case '6': //Location
 		locat = 1 - locat;
@@ -404,24 +417,24 @@ function cmpDateDes(j, iSmaller)
 	return items[j].date > items[iSmaller].date;
 }
 
-function cmpAtempAsc(j, iSmaller)
+function cmpDurAsc(j, iSmaller)
 {
-	return parseFloat(items[j].temperature.air, 10) < parseFloat(items[iSmaller].temperature.air, 10);
+	return items[j].duration < items[iSmaller].duration;
 }
 
-function cmpAtempDes(j, iSmaller)
+function cmpDurDes(j, iSmaller)
 {
-	return parseFloat(items[j].temperature.air, 10) > parseFloat(items[iSmaller].temperature.air, 10);
+	return items[j].duration > items[iSmaller].duration;
 }
 
-function cmpWtempAsc(j, iSmaller)
+function cmpDepthAsc(j, iSmaller)
 {
-	return parseFloat(items[j].temperature.water, 10) < parseFloat(items[iSmaller].temperature.water, 10);
+	return items[j].maxdepth < items[iSmaller].maxdepth;
 }
 
-function cmpWtempDes(j, iSmaller)
+function cmpDepthDes(j, iSmaller)
 {
-	return parseFloat(items[j].temperature.water, 10) > parseFloat(items[iSmaller].temperature.water, 10);
+	return items[j].maxdepth > items[iSmaller].maxdepth;
 }
 
 function sort_it(sortOn, function_)
@@ -543,7 +556,7 @@ function SearchModules(searchfor, searchOptions)
 	if (searchOptions === null) {
 		searchOptions = {};
 		searchOptions.location = searchingModules["location"].enabled;
-		searchOptions.divemaster = searchingModules["divemaster"].enabled;
+		searchOptions.diveguide = searchingModules["diveguide"].enabled;
 		searchOptions.buddy = searchingModules["buddy"].enabled;
 		searchOptions.notes = searchingModules["notes"].enabled;
 		searchOptions.tags = searchingModules["tags"].enabled;
@@ -555,8 +568,8 @@ function SearchModules(searchfor, searchOptions)
 		if (searchOptions.location === true)
 			keywordResult.Union(searchingModules["location"].search(keywords[i]));
 
-		if (searchOptions.divemaster === true)
-			keywordResult.Union(searchingModules["divemaster"].search(keywords[i]));
+		if (searchOptions.diveguide === true)
+			keywordResult.Union(searchingModules["diveguide"].search(keywords[i]));
 
 		if (searchOptions.buddy === true)
 			keywordResult.Union(searchingModules["buddy"].search(keywords[i]));
@@ -612,7 +625,7 @@ SearchModule.prototype.Enter_search_tag = function(tags, diveno)
 	if (!tags)
 		return;
 	for (var i = 0; i < tags.length; i++) {
-		insertIn(tags[i], diveno, this.head);
+		insertIn(tags[i].toLowerCase(), diveno, this.head);
 		numberofwords++;
 	}
 }
@@ -667,7 +680,6 @@ var statsShows;
 */
 function toggleStats()
 {
-	var stats_button = document.getElementById('stats_button');
 	if (statsShows) {
 		statsShows = false;
 		document.getElementById('diveListPanel').style.display = 'block';
@@ -688,8 +700,7 @@ function showStats()
 
 function getDiveStats()
 {
-	var res = "";
-	res += '<table><tr id="stats_header">';
+	var res = '<table><tr id="stats_header">';
 	res += '<td class="statscell">' + translate.Year + '</td><td class="statscell">#</td><td class="statscell">' + translate.Total_Time + '</td><td class="statscell">' + translate.Average_Time + '</td><td class="statscell">' + translate.Shortest_Time + '</td><td class="statscell">' + translate.Longest_Time + '</td><td class="statscell">' + translate.Average_Depth + '</td><td class="statscell">' + translate.Min_Depth + '</td><td class="statscell">' + translate.Max_Depth + '</td><td class="statscell">' + translate.Average_SAC + '</td><td class="statscell">' + translate.Min_SAC + '</td><td class="statscell">' + translate.Max_SAC + '</td><td class="statscell">' + translate.Average_Temp + '</td><td class="statscell">' + translate.Min_Temp + '</td><td class="statscell">' + translate.Max_Temp + '</td>';
 	res += '</tr>';
 	res += getStatsRows();
@@ -735,14 +746,20 @@ function getDefaultColor(){
 function toggleTrips()
 {
 	var trip_button = document.getElementById('trip_button');
+	var controller = document.getElementById('controller');
+	var no_dives_selector = document.getElementById('no_dives_selector');
 	if (tripsShown) {
 		tripsShown = false;
 		trip_button.style.backgroundColor = BACKGROUND_COLOR;
 		viewInPage();
+		controller.style.display = '';
+		no_dives_selector.style.display = '';
 	} else {
 		showtrips();
 		trip_button.style.backgroundColor = HEADER_COLOR;
 		tripsShown = true;
+		dives_controller.style.display = 'none';
+		no_dives_selector.style.display = 'none';
 	}
 }
 
@@ -750,7 +767,7 @@ function showtrips()
 {
 	var divelist = document.getElementById('diveslist');
 	divelist.innerHTML = "";
-	for (var i = 0; i < trips.length; i++) {
+	for (var i = trips.length - 1; i >= 0; i--) {
 		divelist.innerHTML += '<ul id="trip_' + i + '" class="trips" onclick="toggle_trip_expansion(' + i + ')">' +
 				      trips[i].name + ' ( ' + trips[i].dives.length + ' dives)' + '</ul>' + '<div id="trip_dive_list_' + i + '"></div>';
 	};
@@ -773,7 +790,7 @@ function expand_trip(trip)
 	trips[trip].expanded = true;
 	var d = document.getElementById("trip_dive_list_" + trip);
 	for (var j in trips[trip].dives) {
-		d.innerHTML += '<ul id="' + trips[trip].dives[j].number + '" onclick="toggleExpantion(this)" onmouseover="highlight(this)"' +
+		d.innerHTML += '<ul id="' + trips[trip].dives[j].number + '" onclick="toggleExpansion(event, this)" onmouseover="highlight(this)"' +
 			       ' onmouseout="unhighlight(this)">' + getlimited(trips[trip].dives[j]) + '</ul>';
 	}
 }
@@ -805,6 +822,14 @@ var points;  //reference to the samples array of the shown dive.
 var ZERO_C_IN_MKELVIN = 273150;
 var plot1;
 
+function firstNonZero()
+{
+	for(var i = 0; i <= items[dive_id].samples.length-1; i++){
+		if(items[dive_id].samples[i][2] !== 0)
+			return items[dive_id].samples[i][2];
+	}
+}
+
 function lastNonZero()
 {
 	for(var i = items[dive_id].samples.length-1; i >= 0; i--){
@@ -829,8 +854,7 @@ function get_weights_HTML(dive)
 	if (!dive.Weights.length)
 		return "";
 
-	var result = "";
-	result += '<table><tr><td class="words">' + translate.Weight + '</td><td class="words">' + translate.Type + '</td></tr>';
+	var result = '<table><tr><td class="words">' + translate.Weight + '</td><td class="words">' + translate.Type + '</td></tr>';
 	for (var i in dive.Weights) {
 		result += get_weight_HTML(dive.Weights[i]);
 	}
@@ -847,7 +871,8 @@ function get_cylinder_HTML(cylinder)
 	var cEPressure = cylinder.EPressure;
 
 	if (cSPressure === "--") {
-		cSPressure = Math.round(put_pressure_unit(items[dive_id].samples[0][2])).toFixed(1) + " " + pressure_unit;
+		var nonZeroCSPressure = firstNonZero();
+		cSPressure = Math.round(put_pressure_unit(nonZeroCSPressure)).toFixed(1) + " " + pressure_unit;
 	}
 
 	if (cEPressure === "--") {
@@ -855,7 +880,14 @@ function get_cylinder_HTML(cylinder)
 		cEPressure = Math.round(put_pressure_unit(nonZeroCEPressure)).toFixed(1) + " " + pressure_unit;
 	}
 
-	return '<tr><td class="Cyl">' + cylinder.Type + '</td><td class="Cyl">' + cylinder.Size + '</td><td class="Cyl">' + cylinder.WPressure + '</td>' + '<td class="Cyl">' + cSPressure + '</td><td class="Cyl">' + cEPressure + '</td><td class="Cyl">' + cylinder.O2 + '</td></tr>';
+	var pressure_string = cylinder.O2;
+	if (cylinder.O2 !== "Air") {
+		pressure_string = 'O2: ' + cylinder.O2;
+	}
+	if (cylinder.He && cylinder.He !== "0.0%") {
+		pressure_string += ' / He: ' + cylinder.He;
+	}
+	return '<tr><td class="Cyl">' + cylinder.Type + '</td><td class="Cyl">' + cylinder.Size + '</td><td class="Cyl">' + cylinder.WPressure + '</td>' + '<td class="Cyl">' + cSPressure + '</td><td class="Cyl">' + cEPressure + '</td><td class="Cyl">' + pressure_string + '</td></tr>';
 }
 
 /**
@@ -866,8 +898,7 @@ function get_cylinders_HTML(dive)
 	if (!dive.Cylinders.length)
 		return "";
 
-	var result = "";
-	result += '<h2 class="det_hed">' + translate.Dive_equipment + '</h2><table><tr><td class="words">' + translate.Type + '</td><td class="words">' + translate.Size + '</td><td class="words">' + translate.Work_Pressure + '</td><td class="words">' + translate.Start_Pressure + '</td><td class="words">' + translate.End_Pressure + '</td><td class="words">'+translate.Gas+'</td></tr>';
+	var result = '<h2 class="det_hed">' + translate.Dive_equipment + '</h2><table><tr><td class="words">' + translate.Type + '</td><td class="words">' + translate.Size + '</td><td class="words">' + translate.Work_Pressure + '</td><td class="words">' + translate.Start_Pressure + '</td><td class="words">' + translate.End_Pressure + '</td><td class="words">'+translate.Gas+'</td></tr>';
 	for (var i in dive.Cylinders) {
 		result += get_cylinder_HTML(dive.Cylinders[i]);
 	}
@@ -880,7 +911,7 @@ function get_event_value(event)
 	if (event.type == 11 || event.type == 25) { // gas change
 		var he = event.value >> 16;
 		var o2 = event.value & 0xffff;
-		return 'He: ' + he + ' - O2: ' + o2;
+		return 'O2: ' + o2 + ' / He: ' + he;
 	}
 	if (event.type == 23) { // heading
 		return event.value;
@@ -903,8 +934,7 @@ function get_bookmarks_HTML(dive)
 {
 	if (!dive.events || dive.events <= 0)
 		return "";
-	var result = "";
-	result += '<h2 class="det_hed">' + translate.Events + '</h2><table><tr><td class="words">' + translate.Name + '</td><td class="words">' + translate.Time + '</td><td class="words">' + translate.Value + '</td></tr>';
+	var result = '<h2 class="det_hed">' + translate.Events + '</h2><table><tr><td class="words">' + translate.Name + '</td><td class="words">' + translate.Time + '</td><td class="words">' + translate.Value + '</td></tr>';
 	for (var i in dive.events) {
 		result += get_bookmark_HTML(dive.events[i]);
 	}
@@ -912,10 +942,11 @@ function get_bookmarks_HTML(dive)
 	return result;
 }
 
-function getDiveCoorString(coordinates){
-	res = "";
-	lat = coordinates.lat;
-	lon = coordinates.lon;
+function getDiveCoorString(coordinates)
+{
+	var res = "";
+	var lat = coordinates.lat;
+	var lon = coordinates.lon;
 	res += float_to_deg(lat) + ' , ' + float_to_deg(lon);
 	return res;
 }
@@ -924,7 +955,7 @@ function getDiveCoor(dive)
 {
 	if (!dive.coordinates)
 		return "";
-	return '<td class="words">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' + translate.Coordinates + ': </td><td>' + '<a href="http://www.google.com/maps/@' + dive.coordinates.lat + ',' + dive.coordinates.lon + ',13z" target="_blank">' + getDiveCoorString(dive.coordinates) + '</a></td>';
+	return '<td class="words">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' + translate.Coordinates + ': </td><td>' + '<a href="http://maps.google.com/maps?t=k&q=loc:' + dive.coordinates.lat + ',' + dive.coordinates.lon + '" target="_blank">' + getDiveCoorString(dive.coordinates) + '</a></td>';
 }
 
 /**
@@ -932,21 +963,31 @@ function getDiveCoor(dive)
 */
 function get_dive_HTML(dive)
 {
-	var res = '<h2 class="det_hed">' + translate.Dive_information + '</h2><table><tr><td class="words">' + translate.Date + ': </td><td>' + dive.date +
+	var table1 = '<h2 class="det_hed">' + translate.Dive_information + '</h2><table><tr><td class="words">' + translate.Date + ': </td><td>' + dive.date +
 		  '</td><td class="words">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' + translate.Time + ': </td><td>' + dive.time +
-		  '</td><td class="words">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' + translate.Location + ': </td><td>' + '<a onclick=\"Search_list_Modules(\'' + dive.location + '\', {location:true, divemaster:false, buddy:false, notes:false, tags:false,})\">' + dive.location + '</a></td>' + getDiveCoor(dive) +
-		  '</tr></table><table><tr><td class="words">' + translate.Rating + ':</td><td>' + putRating(dive.rating) +
-		  '</td><td class="words">&nbsp;&nbsp;&nbsp;' + translate.Visibility + ':</td><td>' + putRating(dive.visibility) +
-		  '</td></tr></table>' +
-		  '<table><tr><td class="words">' + translate.Air_Temp + ': </td><td>' + dive.temperature.air +
+		  '</td><td class="words">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' + translate.Location + ': </td><td>' + '<a onclick=\"Search_list_Modules(\'' + dive.location + '\', {location:true, diveguide:false, buddy:false, notes:false, tags:false,})\">' + dive.location + '</a></td>' + getDiveCoor(dive) +
+		  '</tr></table>';
+	var table2 = '<table><tr><td class="words">' + translate.Rating + ':</td><td>' + putRating(dive.rating) + '</td>';
+	if (dive.wavesize > 0)
+		 table2 += '<td class="words">&nbsp;&nbsp;&nbsp;' + translate.WaveSize + ':</td><td>' + putRating(dive.wavesize) + '</td>';
+	if (dive.visibility > 0)
+		 table2 += '</td><td class="words">&nbsp;&nbsp;&nbsp;' + translate.Visibility + ':</td><td>' + putRating(dive.visibility) + '</td>';
+	if (dive.current > 0)
+		 table2 += '<td class="words">&nbsp;&nbsp;&nbsp;' + translate.Current + ':</td><td>' + putRating(dive.current) + '</td>';
+	if (dive.surge > 0)
+		 table2 += '<td class="words">&nbsp;&nbsp;&nbsp;' + translate.Surge + ':</td><td>' + putRating(dive.surge) + '</td>';
+	if (dive.chill > 0)
+		 table2 += '<td class="words">&nbsp;&nbsp;&nbsp;' + translate.Chill + ':</td><td>' + putRating(dive.chill) + '</td>';
+	table2 += '</tr></table>';
+	var table3 = '<table><tr><td class="words">' + translate.Air_Temp + ': </td><td>' + dive.temperature.air +
 		  '</td><td class="words">&nbsp;&nbsp;&nbsp;&nbsp;' + translate.Water_Temp + ': </td><td>' + dive.temperature.water +
-		  '</td></tr></table><table><tr><td class="words">' + translate.Duration + ': </td><td>' + dive.dive_duration +
-		  '</td></tr><tr><td class="words">' + translate.DiveMaster + ': </td><td>' + dive.divemaster +
+		  '</td></tr></table><table><tr><td class="words">' + translate.Max_Depth + ': </td><td>' + put_depth_unit(dive.maxdepth) + " " + depth_unit + '</td></tr><tr><td class="words">' + translate.Duration + ': </td><td>' + dive.dive_duration +
+		  '</td></tr><tr><td class="words">' + translate.DiveGuide + ': </td><td>' + dive.diveguide +
 		  '</td></tr><tr><td class="words"><p>' + translate.Buddy + ': </p></td><td>' + dive.buddy +
 		  '</td></tr><tr><td class="words">' + translate.Suit + ': </td><td>' + dive.suit +
 		  '</td></tr><tr><td class="words">' + translate.Tags + ': </td><td>' + putTags(dive.tags) +
 		  '</td></tr></table>'+ put_divecomputer_details(dive.divecomputers) +'<div style="margin:10px;"><p class="words">' + translate.Notes + ': </p>' + dive.notes + '</div>';
-	return res;
+	return table1 + table2 + table3;
 };
 
 function put_divecomputer_details(dc)
@@ -954,8 +995,7 @@ function put_divecomputer_details(dc)
 	if (dc.length <= 0)
 		return;
 
-	var res = '';
-	res += '<p style="margin:10px;" class="words">Divecomputer:</p>';
+	var res = '<p style="margin:10px;" class="words">Divecomputer:</p>';
 	for (var i =0; i < dc.length; i++) {
 		res += '<table>';
 		res += '<tr><td>Model : </td><td>' + dc[i].model + '</td></tr>';
@@ -978,19 +1018,93 @@ function get_status_HTML(dive)
 	       '</td><td class="words">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;CNS: </td><td>' + dive.cns + '</td></tr></table>';
 };
 
-function get_dive_photos(dive)
+/**
+* Dive Photo View
+*/
+
+var success;
+var error;
+var missing_ids;
+
+function show_loaded_photos()
 {
+	//dive photos in the current dive
+	var dive = items[dive_id];
+	var slider = "";
+	document.getElementById("divephotos").style.display = 'block';
+	for (var i = 0; i < dive.photos.length; i++) {
+		slider += '<img src="' + location.pathname + '_files/photos/' + dive.photos[i].filename + '" alt="" height="240" width="240">';
+	}
+	document.getElementById("slider").innerHTML = slider;
+}
+
+function remove_missing_photos()
+{
+	//dive photos in the current dive
+	var dive = items[dive_id];
+	var actually_removed = 0;
+
+	console.log(missing_ids.length);
+	for(var i = 0; i < missing_ids.length; i++){
+		dive.photos.splice(missing_ids[i] - actually_removed, 1);
+		actually_removed++;
+	}
+}
+
+function check_loaded_photos()
+{
+	//hide the photos div if all photos are missing
+	if (error >= items[dive_id].photos.length) {
+		document.getElementById("divephotos").style.display = 'none';
+		return;
+	}
+
+	//remove missing photos from the list
+	remove_missing_photos();
+
+	//view all remaining photos
+	show_loaded_photos();
+}
+
+function check_loading_finished()
+{
+	//if all images wasn't loaded yet
+	if (success + error < items[dive_id].photos.length)
+		return;
+
+	check_loaded_photos();
+}
+
+function load_photo(url, i) {
+	var img = new Image();
+	img.onload = function() {
+		success++;
+		check_loading_finished();
+	};
+	img.onerror = function() {
+		error++;
+		missing_ids.push(i);
+		check_loading_finished();
+	};
+	img.src = url;
+}
+
+function load_all_photos(dive)
+{
+	//init
+	success = 0;
+	error = 0;
+	missing_ids = new Array();
+
+	//exit if no photos in this dive.
 	if (!dive.photos || dive.photos.length <= 0) {
 		document.getElementById("divephotos").style.display = 'none';
 		return "";
 	}
-	var slider = "";
-	document.getElementById("divephotos").style.display = 'block';
+
 	for (var i = 0; i < dive.photos.length; i++) {
-		slider += '<img src="' + location.pathname +
-			  '_files/photos/' + dive.photos[i].filename + '" alt="" height="240" width="240">';
+		load_photo(location.pathname + '_files/photos/' + dive.photos[i].filename, i);
 	}
-	return slider;
 }
 
 function prev_photo()
@@ -1001,7 +1115,7 @@ function prev_photo()
 		items[dive_id].photos[i] = items[dive_id].photos[i + 1]
 	}
 	items[dive_id].photos[i] = temp;
-	document.getElementById("slider").innerHTML = get_dive_photos(items[dive_id]);
+	show_loaded_photos();
 }
 
 function next_photo()
@@ -1012,9 +1126,12 @@ function next_photo()
 		items[dive_id].photos[i] = items[dive_id].photos[i - 1]
 	}
 	items[dive_id].photos[0] = temp;
-	document.getElementById("slider").innerHTML = get_dive_photos(items[dive_id]);
+	show_loaded_photos();
 }
 
+/**
+* Helper functions
+*/
 function mkelvin_to_C(mkelvin)
 {
 	return (mkelvin - ZERO_C_IN_MKELVIN) / 1000.0;
@@ -1032,7 +1149,7 @@ function mbar_to_bar(mbar)
 
 function mbar_to_psi(mbar)
 {
-	return (mbar * 0.0145037738);
+	return mbar * 0.0145037738;
 }
 
 function mm_to_meter(mm)
@@ -1072,7 +1189,7 @@ function int_to_time(n)
 
 function float_to_deg(flt){
 	var deg = 0 | flt;
-	flt = (flt < 0 ? flt =- flt : flt);
+	flt = (flt < 0 ? - flt : flt);
         var min = 0 | flt % 1 * 60;
         var sec = (0 | flt * 60 % 1 * 6000) / 100;
         return deg + "&deg; " + min + "' " + sec + "\"";
@@ -1250,7 +1367,7 @@ function showDiveDetails(dive)
 	document.getElementById("dive_equipment").innerHTML += get_weights_HTML(items[dive_id]);
 	document.getElementById("bookmarks").innerHTML = get_bookmarks_HTML(items[dive_id]);
 	document.getElementById("divestats").innerHTML = get_status_HTML(items[dive_id]);
-	document.getElementById("slider").innerHTML = get_dive_photos(items[dive_id]);
+	load_all_photos(items[dive_id]);
 	setDiveTitle(items[dive_id]);
 
 	//hide the list of dives and show the canvas.
@@ -1328,8 +1445,8 @@ function translate_page()
 	document.getElementById("date_header").innerHTML = translate.Date;
 	document.getElementById("time_header").innerHTML = translate.Time;
 	document.getElementById("location_header").innerHTML = translate.Location;
-	document.getElementById("air_temp_header").innerHTML = translate.Air_Temp;
-	document.getElementById("water_temp_header").innerHTML = translate.Water_Temp;
+	document.getElementById("duration_header").innerHTML = translate.Duration;
+	document.getElementById("maxdepth_header").innerHTML = translate.Max_Depth;
 	document.getElementById("adv_srch_sp").innerHTML = translate.Advanced_Search;
 	document.getElementById("expnd_all_btn").innerHTML = translate.Expand_All;
 	document.getElementById("claps_all_btn").innerHTML = translate.Collapse_All;
